=============
Reference/API
=============

.. toctree::
  :maxdepth: 1

Operations on Spectroscopic Data
================================

.. automodapi:: speclite.accumulate
.. automodapi:: speclite.downsample
.. automodapi:: speclite.resample
.. automodapi:: speclite.redshift

Operations with Filters
=======================

.. _filters-api:

.. automodapi:: speclite.filters
    :no-inheritance-diagram:
